/****************************************************************
PROJECT BORNED FOR ARDUINO:
  https://github.com/stephanedenis/AudioControlPT2257?files=1

REWRITE FOR PIC MIKROC VER.7.2 MCU:18F2550 BY LEO M.

COMMAND:
    writeVolume(int dB); (dB=0 == Max Volume)
    increase()
    decrease()
    toggleMute()
    getVolume()
    getMute()
    serialPrintStateJSON()
IMPORTANT:
In main insert I2C initialization function for I2C devices, follow:
I2C1_Init(400000);
This Library work for MikroC ver.7.2 (not minor version)
****************************************************************/

#include <stdbool.h>
#include "\PT2257_Volume_CTRL\PT2257_Vol_CTRL__Lib_v1_0.h"

#define TAB 9
#define CLS 12
const char MESSAGE1[]=" !! ERROR on READ I2C bus, control PT2257 chip !! \r\n";
const char MESSAGE2[]=" !! ERROR on WRITE I2C bus, control PT2257 chip !! \r\n";

static int volume = 40;
static bool mute = false;

unsigned char VOLUME_TXT[6];

void test(char err) {
if(err == _I2C_TIMEOUT_RD) {
       UART1_Write(MESSAGE1); //RA0_bit=1;
       }
if(err == _I2C_TIMEOUT_WR) {
       UART1_Write(MESSAGE2); //RA1_bit=1;
       }
}

void PT2257_Init(void) {
    I2C1_SetTimeoutCallback(1000, &test);
}

void increase(void) {
  volume++;
  if (volume > 79) { volume = 79; }

  writeVolume(volume);

  if (mute) {
    mute = false;
    writeMute(mute);
  }
}

void decrease(void) {
  volume--;
  if (volume < 0)volume = 0;

  writeVolume(volume);

  if (mute) {
    mute = false;
    writeMute(mute);
  }
}

void toggleMute(void) {
  if (mute) mute = false;
  else mute = true;
  writeMute(mute);
}

void serialPrintStateJSON(void) {
  UART1_Write_Text(" Volume dB:");
  IntToStr(volume, VOLUME_TXT); 
  UART1_Write_Text(VOLUME_TXT);
  UART1_Write(TAB);
  UART1_Write_Text(" Mute:");
  IntToStr(mute, VOLUME_TXT);
  UART1_Write_Text(VOLUME_TXT);
  UART1_Write_Text("\r\n");
}

unsigned char level(int dB) {
  unsigned int b;
  unsigned int a;
  volume=dB;
  if (dB > 79) { dB = 79; }

  b = (dB / 10); //get the second digit
  a = (dB % 10); //get the first digit
  b = b & 0b0000111; //limit the most significant digit to 3 bit (7)

  return (b << 4) | a; //return both numbers in one byte (0BBBAAAA)
}


void writeVolume(int dB) {
  unsigned char bbbaaaa = level(dB);
  unsigned char aaaa = bbbaaaa & 0b00001111;
  unsigned char bbb = (bbbaaaa >> 4) & 0b00001111;
     //if(dB<0) dB=volume=0;
     //if(dB>79) dB=volume=79;
     I2C1_Start();
     I2C1_Wr(PT2257_ADDR);      // 0x88
     I2C1_Wr(EVC_2CH_10 | bbb);
     I2C1_Wr(EVC_2CH_1 | aaaa);
     I2C1_Stop();
  //  }
}

void writeMute(bool state) {
  I2C1_Start();
  I2C1_Wr(PT2257_ADDR);   //0x88
  I2C1_Wr(EVC_MUTE | (state & 0b00000001));
  I2C1_Stop();
}

void off(void) {
  I2C1_Start();
  I2C1_Wr(PT2257_ADDR);       //0x88
  I2C1_Wr(EVC_OFF);
  I2C1_Stop();
}

int getVolume(void){
  return volume;
}

bool getMute(void){
  return mute;
}